package com.logicbig.example;

import javax.persistence.Cache;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;

public class ExampleMain {
    private static EntityManagerFactory entityManagerFactory =
            Persistence.createEntityManagerFactory("example-unit");

    public static void main(String[] args) {
        try {
            persistEntities();
            loadEntity();
        } finally {
            entityManagerFactory.close();
        }
    }

    public static void persistEntities() {
        Employee employee = new Employee();
        employee.setName("Dawn");
        employee.setDept("IT");
        Task task = new Task();
        task.setDescription("UI Coding");
        EntityManager em = entityManagerFactory.createEntityManager();
        em.getTransaction().begin();
        em.persist(employee);
        em.persist(task);
        em.getTransaction().commit();
        System.out.println("Employee persisted: " + employee);
        System.out.println("Task persisted: " + task);
        em.close();
        printCacheState();
    }

    private static void loadEntity() {
        EntityManager em = entityManagerFactory.createEntityManager();
        Employee employee = em.find(Employee.class, 1L);
        System.out.println("Employee loaded: " + employee);
        Task task = em.find(Task.class, 2L);
        System.out.println("Task loaded: " + task);
        em.close();
        printCacheState();
    }

    private static void printCacheState() {
        Cache cache = entityManagerFactory.getCache();
        boolean contains = cache.contains(Employee.class, 1L);
        System.out.printf("Cache#contains() for Employee: %5s%n", contains);
        contains = cache.contains(Task.class, 2L);
        System.out.printf("Cache#contains() for Task: %10s%n", contains);
    }
}